"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = exports.LogOptions = exports.LogLevel = void 0;
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["error"] = 0] = "error";
    LogLevel[LogLevel["info"] = 1] = "info";
    LogLevel[LogLevel["debug"] = 2] = "debug";
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
class LogOptions {
    constructor() {
        this.level = LogLevel.info;
        this.prettyIndent = 0;
    }
}
exports.LogOptions = LogOptions;
class Logger {
    constructor(options, storage, append = false) {
        this.storage = storage;
        this.enabled = true;
        this.options = {
            level: LogLevel.info,
            prettyIndent: 0
        };
        if (options) {
            this.options = { ...this.options, ...options };
        }
        if (storage && !append) {
            storage.remove();
        }
    }
    log(level, message, obj) {
        if (level <= this.options.level) {
            if (level === LogLevel.error) {
                if (obj) {
                    if (obj.stack) {
                        console.error(message);
                        console.error(obj.stack);
                    }
                    else {
                        console.error(message + ': ' + JSON.stringify(obj, null, this.options.prettyIndent));
                    }
                }
                else {
                    console.error(message);
                }
            }
            else {
                if (obj) {
                    if (obj.stack) {
                        console.log(message);
                        console.log(obj);
                    }
                    else {
                        console.log(message + ': ' + JSON.stringify(obj, null, this.options.prettyIndent));
                    }
                }
                else {
                    console.log(message);
                }
            }
            if (this.storage) {
                this.storage.append('' + message);
                if (obj) {
                    if (obj.stack) {
                        this.storage.append('\n' + obj.stack);
                    }
                    else {
                        this.storage.append(': ' + JSON.stringify(obj, null, this.options.prettyIndent));
                    }
                }
                this.storage.append('\n');
            }
        }
    }
    info(message, obj) {
        this.log(LogLevel.info, message, obj);
    }
    error(message, obj) {
        if (!obj && message.message && message.stack) {
            const err = message;
            this.log(LogLevel.error, err.message, err);
        }
        else {
            this.log(LogLevel.error, message, obj);
        }
    }
    debug(message, obj) {
        this.log(LogLevel.debug, message, obj);
    }
    get level() {
        return this.options.level;
    }
    toString() {
        return this.options.level + ': ' + (this.storage ? this.storage : 'console');
    }
}
exports.Logger = Logger;
//# sourceMappingURL=logger.js.map