"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlyResponse = void 0;
const stringify = require("json-stable-stringify");
class PlyResponse {
    constructor(runId, status, headers, body, time) {
        this.runId = runId;
        this.status = status;
        this.headers = headers;
        this.body = body;
        this.time = time;
    }
    /**
     * Orders body object keys unless suppressed by options.  Does not substitute values.
     * Response header keys are always lowercase
     * @param runtime runtime context
     * @param wantedHeaders optional name of headers subset to keep
     * @param stringBody body object is stringified
     */
    getResponse(runId, options, wantedHeaders, stringBody = false) {
        const headers = {};
        const headerNames = wantedHeaders || Object.keys(this.headers);
        headerNames.forEach(h => {
            headers[h.toLowerCase()] = this.headers[h];
        });
        let body = this.body;
        if (typeof body === 'string' && (body.startsWith('{') || body.startsWith('['))) {
            try {
                body = JSON.parse(body);
            }
            catch (err) {
                // cannot parse -- body remains string
            }
        }
        if (stringBody && typeof body === 'object') {
            if (options.responseBodySortedKeys) {
                body = stringify(body, { space: ''.padStart(options.prettyIndent || 0, ' ') });
            }
            else {
                body = JSON.stringify(body, null, options.prettyIndent);
            }
        }
        return new PlyResponse(runId, this.status, headers, body, this.time);
    }
}
exports.PlyResponse = PlyResponse;
//# sourceMappingURL=response.js.map